# ktch - A python package for model-based morphometrics

[![codecov](https://codecov.io/gh/noshita/ktch/branch/main/graph/badge.svg?token=SJN66K7KJY)](https://codecov.io/gh/noshita/ktch)

ktch is a python package for model-based morphometrics.

## Usage

```sh
pip install ktch
```


## License

ktch is licensed under the Apache License, Version2.0
